@@ -2,27 +2,30 @@ package Catalyst::TraitFor::Request::Methods;
 
 # ABSTRACT: Add enumerated methods for HTTP requests
 
+use v5.10.1;
+
 use Moose::Role;
 
+use Data::Enum;
+
 use namespace::autoclean;
 
 requires 'method';
 
-our $VERSION = 'v0.2.3';
+our $VERSION = 'v0.3.0';
 
 
-foreach my $name (qw/ get head post put delete connect options trace patch /) {
+my @METHODS = qw/ get head post put delete connect options trace patch /;
 
-    my $value = uc $name;
-    my $method = "is_$name";
-
-    has $method => (
-        is      => 'ro',
-        lazy    => 1,
-        default => sub { return $_[0]->method eq $value },
-    );
-
-}
+has _method_enum => (
+    is => 'ro',
+    lazy => 1,
+    default => sub {
+        state $enum = Data::Enum->new(@METHODS);
+        return $enum->new( lc $_[0]->method );
+    },
+    handles => [ map { "is_" . $_ } @METHODS ],
+);
 
 
 1;
@@ -39,7 +42,7 @@ Catalyst::TraitFor::Request::Methods - Add enumerated methods for HTTP requests
 
 =head1 VERSION
 
-version v0.2.3
+version v0.3.0
 
 =head1 SYNOPSIS
 
@@ -137,7 +140,7 @@ Robert Rothenberg <rrwo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2019-2020 by Robert Rothenberg.
+This software is Copyright (c) 2019-2022 by Robert Rothenberg.
 
 This is free software, licensed under:
 
